#include <iostream>
#include <cmath>

#include <ros/ros.h>
#include <nav_msgs/Odometry.h>
#include <tf/transform_datatypes.h>

void callBackOdom(const nav_msgs::Odometry::ConstPtr& odom_msg_ptr)
{
    double odom_roll_rad, odom_pitch_rad, odom_yaw_rad;
    tf::Quaternion q(odom_msg_ptr->pose.pose.orientation.x, odom_msg_ptr->pose.pose.orientation.y, odom_msg_ptr->pose.pose.orientation.z, odom_msg_ptr->pose.pose.orientation.w);
    tf::Matrix3x3 m(q);
    m.getRPY(odom_roll_rad, odom_pitch_rad, odom_yaw_rad);
    std::cout << odom_msg_ptr->pose.pose.position.x << " " << odom_msg_ptr->pose.pose.position.y << " " << odom_yaw_rad/M_PI*180.0 << std::endl;
}
	
int main(int argc, char **argv)
{
    ros::init(argc, argv, "ypspur_run_test");
    ros::NodeHandle private_node_handle("~");
    ros::NodeHandle public_node_handle;

    double linear = 0.1;
    double angular = 0.0;
    private_node_handle.param<double>("linear", linear, linear);
    private_node_handle.param<double>("angular", angular, angular);

	ros::Publisher cmd_publisher = public_node_handle.advertise<geometry_msgs::Twist>("cmd_vel", 100);
    ros::Subscriber odom_subscriber = public_node_handle.subscribe<nav_msgs::Odometry>("odom", 1, callBackOdom);

    ros::Rate rate(20);

    while (ros::ok())
    {
    	geometry_msgs::Twist cmd_vel_msg;
    	cmd_vel_msg.linear.x = linear;
    	cmd_vel_msg.angular.z = angular;

    	cmd_publisher.publish(cmd_vel_msg);
        ros::spinOnce();
        rate.sleep();
    }
    return 0;
}